<?php

/**
 * WC_PayLate_Gateway class file.
 *
 * @package woo-paylate
 */

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

/**
 * Class WC_PayLate_Gateway
 */
class WC_PayLate_Gateway extends WC_Payment_Gateway
{
    /**
     * Default port.
     */
    const  DEFAULT_PORT = '443' ;
    /**
     * Default test port.
     */
    const  DEFAULT_TEST_PORT = '21443' ;
    /**
     * Plugin id.
     *
     * @var string
     */
    public  $id ;
    /**
     * Plugin icon.
     *
     * @var string
     */
    public  $icon ;
    /**
     * Plugin method title - required by WooCommerce.
     *
     * @var string
     */
    public  $method_title ;
    /**
     * Plugin method description - required by WooCommerce.
     *
     * @var string
     */
    public  $method_description ;
    /**
     * Plugin has fields ( = false ).
     *
     * @var string
     */
    public  $has_fields ;
    /**
     * Plugin supports ( = products ).
     *
     * @var string
     */
    public  $supports ;
    /**
     * Whether or not logging is enabled.
     *
     * @var bool
     */
    public static  $log_enabled = false ;
    /**
     * WC_Logger Logger instance.
     *
     * @var bool
     */
    public static  $log = false ;
    /**
     * Test mode (yes or no).
     *
     * @var string
     */
    protected  $test_mode ;
    /**
     * Port number given by PayLate service.
     *
     * @var string
     */
    protected  $port ;
    /**
     * Client ID  given by PayLate service.
     *
     * @var string
     */
    protected  $client_id ;
    /**
     * Login given by PayLate service.
     *
     * @var string
     */
    protected  $login ;
    /**
     * Password given by PayLate service.
     *
     * @var string
     */
    protected  $password ;
    /**
     * Test order id.
     */
    const  TEST_ORDER_ID = 235 ;
    /**
     * WC_PayLate_Gateway constructor.
     */
    public function __construct()
    {
        $this->id = 'paylate_gateway';
        $this->icon = WOO_PAYLATE_URL . '/images/paylate-logo-32x32.png';
        $this->method_title = __( 'PayLate', 'woo-paylate' );
        $this->method_description = __( 'WooCommerce gateway to make payments via PayLate service', 'woo-paylate' );
        $this->has_fields = false;
        $this->supports = array( 'products' );
        $this->init_form_fields();
        $this->init_settings();
        // Load settings.
        $this->enabled = $this->get_option( 'enabled' );
        if ( !wc_paylate_fs()->is_plan( 'premium' ) ) {
            $this->enabled = 'no';
        }
        $this->title = $this->get_option( 'title' );
        $this->description = $this->get_option( 'description' );
        self::$log_enabled = $this->get_option( 'log_enabled' );
        
        if ( 'yes' === $this->test_mode ) {
            $this->port = $this->get_option( 'test_port', $this->form_fields['test_port']['default'] );
            $this->client_id = $this->get_option( 'test_client_id' );
            $this->login = $this->get_option( 'test_login' );
            $this->password = $this->get_option( 'test_password' );
        } else {
            $this->port = $this->get_option( 'port', $this->form_fields['port']['default'] );
            $this->client_id = $this->get_option( 'client_id' );
            $this->login = $this->get_option( 'login' );
            $this->password = $this->get_option( 'password' );
        }
        
        add_filter( 'woocommerce_payment_gateways', array( $this, 'add_paylate_gateway_class' ) );
        add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
        add_filter(
            'script_loader_tag',
            array( $this, 'script_loader_tag_filter' ),
            10,
            2
        );
        add_shortcode( 'paylate_widget', array( $this, 'paylate_widget_shortcode' ) );
        add_shortcode( 'paylate_buy_button', array( $this, 'paylate_buy_button_shortcode' ) );
        add_action( 'admin_menu', array( $this, 'add_settings_page' ), 100 );
        // Save settings.
        if ( is_admin() ) {
            add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
        }
    }
    
    /**
     * Initialize form fields on admin page.
     */
    public function init_form_fields()
    {
        $this->form_fields = array(
            'enabled'     => array(
            'title'   => __( 'Enable', 'woo-paylate' ),
            'type'    => 'checkbox',
            'label'   => __( 'Enable PayLate Gateway', 'woo-paylate' ),
            'default' => 'yes',
        ),
            'title'       => array(
            'title'       => __( 'Title', 'woo-paylate' ),
            'type'        => 'text',
            'description' => __( 'Payment method title that the customer will see on checkout.', 'woo-paylate' ),
            'default'     => __( 'PayLate Gateway', 'woo-paylate' ),
            'desc_tip'    => true,
        ),
            'description' => array(
            'title'       => __( 'Description', 'woo-paylate' ),
            'type'        => 'textarea',
            'description' => __( 'Payment method description that the customer will see on checkout.', 'woo-paylate' ),
            'default'     => __( 'Pay via PayLate Gateway', 'woo-paylate' ),
            'desc_tip'    => true,
        ),
            'log_enabled' => array(
            'title'       => __( 'Log', 'woo-paylate' ),
            'type'        => 'checkbox',
            'label'       => __( 'Enable logging', 'woo-paylate' ),
            'default'     => 'no',
            'description' => __( 'Log events, such as PayLate responses, inside', 'woo-paylate' ) . ' <code>' . WC_Log_Handler_File::get_log_file_path( 'paylate' ) . '</code>',
        ),
            'test_mode'   => array(
            'title'       => __( 'Test mode', 'woo-paylate' ),
            'type'        => 'checkbox',
            'description' => __( 'Fields below have different values in test mode.', 'woo-paylate' ),
            'label'       => __( 'Enable test mode', 'woo-paylate' ),
            'default'     => 'no',
        ),
        );
        $this->test_mode = $this->get_option( 'test_mode' );
        
        if ( 'yes' === $this->test_mode ) {
            $var_form_fields = array(
                'test_port'      => array(
                'title'       => __( 'Test Port', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Test Port number given by PayLate service.', 'woo-paylate' ),
                'default'     => self::DEFAULT_TEST_PORT,
                'desc_tip'    => true,
            ),
                'test_client_id' => array(
                'title'       => __( 'Test Client ID', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Test Client ID given by PayLate service.', 'woo-paylate' ),
                'default'     => '1524072013',
                'desc_tip'    => true,
            ),
                'test_login'     => array(
                'title'       => __( 'Test Login', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Test Login for PayLate service.', 'woo-paylate' ),
                'default'     => 'test',
                'desc_tip'    => true,
            ),
                'test_password'  => array(
                'title'       => __( 'Test Password', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Test Password for PayLate service.', 'woo-paylate' ),
                'default'     => 'test',
                'desc_tip'    => true,
            ),
            );
        } else {
            $var_form_fields = array(
                'port'      => array(
                'title'       => __( 'Port', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Port number given by PayLate service.', 'woo-paylate' ),
                'default'     => self::DEFAULT_PORT,
                'desc_tip'    => true,
            ),
                'client_id' => array(
                'title'       => __( 'Client ID', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Client ID given by PayLate service.', 'woo-paylate' ),
                'default'     => '',
                'desc_tip'    => true,
            ),
                'login'     => array(
                'title'       => __( 'Login', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Login for PayLate service.', 'woo-paylate' ),
                'default'     => '',
                'desc_tip'    => true,
            ),
                'password'  => array(
                'title'       => __( 'Password', 'woo-paylate' ),
                'type'        => 'text',
                'description' => __( 'Password for PayLate service.', 'woo-paylate' ),
                'default'     => '',
                'desc_tip'    => true,
            ),
            );
        }
        
        $this->form_fields = array_merge( $this->form_fields, $var_form_fields );
    }
    
    /**
     * Process payment via PayLate interface.
     *
     * @param int $order_id Order id in WooCommerce.
     *
     * @return array
     */
    public function process_payment( $order_id )
    {
        return null;
    }
    
    /**
     * Get payment link.
     *
     * @param array  $goods    Ordered products.
     * @param int    $order_id Order id.
     * @param string $all_cats List of ordered product categories, separated by comma.
     *
     * @return string Payment link.
     */
    private function get_payment_link( $goods, $order_id, $all_cats )
    {
        return null;
    }
    
    /**
     * Function to check response from PayLate service.
     *
     * @return bool|null
     */
    public function check_response()
    {
        return null;
    }
    
    /**
     * Add PayLate gateway class in WooCommerce payment methods.
     *
     * @param array $methods - array of WooCommerce payment methods.
     *
     * @return array
     */
    public function add_paylate_gateway_class( $methods )
    {
        $methods[] = 'WC_PayLate_Gateway';
        return $methods;
    }
    
    /**
     * Logging method.
     *
     * @param string $message Log message.
     * @param string $level   Optional. Default 'info'
     *                        emergency|alert|critical|error|warning|notice|info|debug.
     */
    public static function log( $message, $level = 'info' )
    {
        
        if ( self::$log_enabled ) {
            if ( empty(self::$log) ) {
                self::$log = wc_get_logger();
            }
            self::$log->log( $level, $message, array(
                'source' => 'paylate',
            ) );
        }
    
    }
    
    /**
     * Enqueue plugin scripts.
     */
    public function enqueue_scripts()
    {
        // Script for paylate_buy_button_shortcode.
        wp_enqueue_script(
            'wc-paylate-partner',
            'https://paylate.ru:' . $this->port . '/js/partner_im.js',
            array(),
            WOO_PAYLATE_VERSION,
            false
        );
        // Script for paylate_widget_shortcode.
        wp_enqueue_script(
            'wc-paylate-widget',
            'https://paylate.ru:' . $this->port . '/widget/js/widget.js',
            array(),
            WOO_PAYLATE_VERSION,
            true
        );
        // This plugin styles.
        wp_enqueue_style(
            'wc-paylate',
            WOO_PAYLATE_URL . '/css/style.css',
            array(),
            WOO_PAYLATE_VERSION
        );
    }
    
    /**
     * Filter script tag and add charset.
     *
     * @param string $tag    Script tag.
     * @param string $handle Script handle.
     *
     * @return mixed
     */
    public function script_loader_tag_filter( $tag, $handle )
    {
        $handles = array( 'wc-paylate-partner', 'wc-paylate-widget' );
        if ( in_array( $handle, $handles, true ) ) {
            $tag = str_replace( '></script>', ' charset="utf-8"></script>', $tag );
        }
        return $tag;
    }
    
    /**
     * Add settings page to the menu.
     */
    public function add_settings_page()
    {
        $parent_slug = 'woocommerce';
        $page_title = __( 'PayLate', 'woo-paylate' );
        $menu_title = __( 'PayLate', 'woo-paylate' );
        $capability = 'manage_options';
        $menu_slug = 'wc-paylate';
        $function = array( $this, 'woocommerce_paylate_settings_page' );
        add_submenu_page(
            $parent_slug,
            $page_title,
            $menu_title,
            $capability,
            $menu_slug,
            $function
        );
    }
    
    /**
     * Empty settings page.
     */
    public function woocommerce_paylate_settings_page()
    {
        ?>
		<div class="wrap">
			<h2 id="title">
				<?php 
        // Admin panel title.
        esc_html_e( 'WooCommerce Paylate Plugin Options', 'woo-paylate' );
        ?>
			</h2>
			<p>
				<a href="<?php 
        echo  esc_url( admin_url( 'admin.php?page=wc-settings&tab=checkout&section=paylate_gateway' ) ) ;
        ?>">
					<?php 
        esc_html_e( 'Please follow this link to see plugin options.', 'woo-paylate' );
        ?>
				</a>
			</p>
		</div>
		<?php 
    }
    
    /**
     * Widget shortcode.
     *
     * @param array $atts Shortcode parameters.
     *
     * @return string Button html.
     */
    public function paylate_widget_shortcode( $atts )
    {
        $atts = shortcode_atts( array(
            'class'       => '',
            'data-button' => '',
        ), $atts );
        $class = $atts['class'];
        if ( !$class ) {
            $class = 'wc-paylate-btn';
        }
        ob_start();
        echo  '<div class="paylate-mini-widget ' . esc_attr( $class ) . '"' ;
        $data_button = intval( $atts['data-button'] );
        if ( $data_button >= 1 && $data_button <= 4 ) {
            echo  ' data-button="' . intval( $data_button ) . '"' ;
        }
        echo  ' href="#">' . esc_html__( 'How to buy in installments', 'woo-paylate' ) . '</div>' ;
        return ob_get_clean();
    }
    
    /**
     * Buy button shortcode.
     *
     * @param array $atts Shortcode parameters.
     *
     * @return string Button html.
     */
    public function paylate_buy_button_shortcode( $atts )
    {
        $atts = shortcode_atts( array(
            'name'     => '',
            'category' => '',
            'price'    => 0,
            'count'    => 1,
            'fio'      => '',
            'passport' => '',
            'type'     => 0,
        ), $atts );
        $atts['price'] = intval( $atts['price'] );
        if ( 0 > $atts['price'] ) {
            $atts['price'] = 0;
        }
        $atts['count'] = intval( $atts['count'] );
        if ( 0 > $atts['count'] ) {
            $atts['count'] = 0;
        }
        $atts['type'] = intval( $atts['type'] );
        if ( 0 > $atts['type'] || 3 < $atts['type'] ) {
            $atts['type'] = 0;
        }
        if ( '' === $atts['name'] || 0 === $atts['price'] || 0 === $atts['count'] ) {
            return __( 'Invalid parameter: name, price or count', 'woo-paylate' );
        }
        $cur_item['Name'] = $atts['name'];
        if ( '' !== $atts['category'] ) {
            $cur_item['Category'] = $atts['category'];
        }
        $cur_item['Price'] = $atts['price'];
        $cur_item['Count'] = $atts['count'];
        if ( '' !== $atts['fio'] ) {
            $cur_item['fio'] = $atts['fio'];
        }
        if ( '' !== $atts['passport'] ) {
            $cur_item['passport'] = $atts['passport'];
        }
        $goods[] = $cur_item;
        
        if ( 'yes' === $this->test_mode ) {
            $order_id = self::TEST_ORDER_ID;
        } else {
            $order_id = 0;
        }
        
        $all_cats = $atts['category'];
        $token = md5( $this->login . md5( $this->password ) . $order_id );
        ob_start();
        ?>
		<script>
			// Установка параметров
			const SetPayLate = {
				client_id: '<?php 
        echo  esc_html( $this->client_id ) ;
        ?>',
				order_id: <?php 
        echo  intval( $order_id ) ;
        ?>,
				category: '<?php 
        echo  esc_html( $all_cats ) ;
        ?>',
				goods: '<?php 
        echo  wp_json_encode( $goods, JSON_UNESCAPED_UNICODE ) ;
        ?>',
				autostart: false,
				token: '<?php 
        echo  esc_html( $token ) ;
        ?>',
				image_type: <?php 
        echo  esc_html( $atts['type'] ) ;
        ?>
			};

			// Отображение кнопки
			PayLateButton( SetPayLate );
		</script>
		<?php 
        return ob_get_clean();
    }

}