<?php

/**
 * WC_PayLate_Plugin class file.
 *
 * @package woo-paylate
 */

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

/**
 * Class WC_PayLate_Plugin
 */
class WC_PayLate_Plugin
{
    /**
     * Required plugins.
     *
     * @var array
     */
    protected  $required_plugins = array() ;
    /**
     * Whether or not logging is enabled.
     *
     * @var bool
     */
    public static  $log_enabled = false ;
    /**
     * WC_Logger Logger instance.
     *
     * @var bool
     */
    public static  $log = false ;
    /**
     * WC_PayLate_Plugin constructor.
     */
    public function __construct()
    {
        $this->required_plugins = array( array(
            'plugin' => 'woocommerce/woocommerce.php',
            'name'   => 'WooCommerce',
            'slug'   => 'woocommerce',
            'class'  => 'WooCommerce',
            'active' => false,
        ) );
        $options = get_option( 'woocommerce_paylate_gateway_settings' );
        self::$log_enabled = $options['log_enabled'];
    }
    
    /**
     * Maybe run plugin.
     */
    public function maybe_run()
    {
        add_action( 'admin_init', array( $this, 'check_requirements' ) );
        if ( !$this->requirements_met() ) {
            return;
        }
        add_action( 'plugins_loaded', array( $this, 'bootstrap' ) );
        add_filter( 'plugin_action_links_' . plugin_basename( WOO_PAYLATE_FILE ), array( $this, 'add_settings_link' ), 10 );
        add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );
    }
    
    /**
     * Bootstrap plugin on 'plugins_loaded' event.
     */
    public function bootstrap()
    {
        static  $gateway ;
        if ( !isset( $gateway ) ) {
            $gateway = new WC_PayLate_Gateway();
        }
    }
    
    /**
     * Check plugin requirements. If not met, show message and deactivate plugin.
     */
    public function check_requirements()
    {
        
        if ( !$this->requirements_met() ) {
            add_action( 'admin_notices', array( $this, 'show_plugin_not_found_notice' ) );
            
            if ( is_plugin_active( plugin_basename( WOO_PAYLATE_FILE ) ) ) {
                deactivate_plugins( plugin_basename( WOO_PAYLATE_FILE ) );
                // @todo Check nonce.
                // @codingStandardsIgnoreStart
                if ( isset( $_GET['activate'] ) ) {
                    unset( $_GET['activate'] );
                }
                // @codingStandardsIgnoreEnd
                add_action( 'admin_notices', array( $this, 'show_deactivate_notice' ) );
            }
        
        }
    
    }
    
    /**
     * Check if plugin requirements met.
     *
     * @return bool Requirements met.
     */
    private function requirements_met()
    {
        $all_active = true;
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
        foreach ( $this->required_plugins as $key => $required_plugin ) {
            
            if ( is_plugin_active( $required_plugin['plugin'] ) ) {
                $this->required_plugins[$key]['active'] = true;
            } else {
                $all_active = false;
            }
        
        }
        return $all_active;
    }
    
    /**
     * Show required plugins not found message.
     */
    public function show_plugin_not_found_notice()
    {
        $message = __( 'WooCommerce PayLate plugin requires the following plugins installed and activated: ', 'woo-paylate' );
        $message_parts = array();
        foreach ( $this->required_plugins as $key => $required_plugin ) {
            
            if ( !$required_plugin['active'] ) {
                $href = '/wp-admin/plugin-install.php?tab=plugin-information&plugin=';
                $href = $href . $required_plugin['slug'] . '&TB_iframe=true&width=640&height=500';
                $message_parts[] = '<em><a href="' . $href . '" class="thickbox">' . $required_plugin['name'] . '</a></em>';
            }
        
        }
        $count = count( $message_parts );
        foreach ( $message_parts as $key => $message_part ) {
            if ( 0 !== $key ) {
                
                if ( $count - 1 === $key ) {
                    $message .= ' and ';
                } else {
                    $message .= ', ';
                }
            
            }
            $message .= $message_part;
        }
        $message .= '.';
        $this->admin_notice( $message, 'notice notice-error is-dismissible' );
    }
    
    /**
     * Show a notice to inform the user that the plugin has been deactivated.
     */
    public function show_deactivate_notice()
    {
        $this->admin_notice( __( 'WooCommerce PayLate plugin has been deactivated.', 'woo-paylate' ), 'notice notice-info is-dismissible' );
    }
    
    /**
     * Show admin notice.
     *
     * @param string $message Message to show.
     * @param string $class   Message class: notice notice-success notice-error notice-warning notice-info
     *                        is-dismissible.
     */
    private function admin_notice( $message, $class )
    {
        ?>
		<div class="<?php 
        echo  esc_attr( $class ) ;
        ?>">
			<p>
				<span style="display: block; margin: 0.5em 0.5em 0 0; clear: both;">
				<?php 
        echo  wp_kses( $message, wp_kses_allowed_html( 'post' ) ) ;
        ?>
				</span>
			</p>
		</div>
		<?php 
    }
    
    /**
     * Load plugin text domain.
     */
    public function load_textdomain()
    {
        load_plugin_textdomain( 'woo-paylate', false, dirname( plugin_basename( WOO_PAYLATE_FILE ) ) . '/languages/' );
    }
    
    /**
     * Add link to plugin setting page on plugins page.
     *
     * @param array $links Plugin links.
     *
     * @return array|mixed Plugin links
     */
    public function add_settings_link( $links )
    {
        $action_links = array(
            'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout&section=paylate_gateway' ) . '" aria-label="' . esc_attr__( 'View WooCommerce PayLate settings', 'woo-paylate' ) . '">' . esc_html__( 'Settings', 'woo-paylate' ) . '</a>',
        );
        return array_merge( $action_links, $links );
    }
    
    /**
     * Function to check if request to WordPress is related to this WooCommerce PayLate Gateway plugin.
     */
    public function check_for_paylate()
    {
    }
    
    /**
     * Logging method.
     *
     * @param string $message Log message.
     * @param string $level   Optional. Default 'info'
     *                        emergency|alert|critical|error|warning|notice|info|debug.
     */
    public static function log( $message, $level = 'info' )
    {
        
        if ( self::$log_enabled ) {
            if ( empty(self::$log) ) {
                self::$log = wc_get_logger();
            }
            self::$log->log( $level, $message, array(
                'source' => 'paylate',
            ) );
        }
    
    }

}