<?php

/**
 * Plugin Name: WooCommerce PayLate
 * Plugin URI: https://wordpress.org/plugins/woo-paylate/
 * Description: WooCommerce payment gateway for PayLate service.
 * Author: KAGG Design
 * Version: 1.3.1
 * Author URI: https://kagg.eu/en/
 * Requires at least: 4.4
 * Tested up to: 5.1
 * Requires PHP: 5.4.0
 * WC requires at least: 3.0
 * WC tested up to: 3.5
 *
 * Text Domain: woo-paylate
 * Domain Path: /languages/
 *
 * @package woo-paylate
 * @author  KAGG Design
 */

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !defined( 'WOO_PAYLATE_PATH' ) ) {
    /**
     * Path to the plugin dir.
     */
    define( 'WOO_PAYLATE_PATH', dirname( __FILE__ ) );
}
if ( !defined( 'WOO_PAYLATE_URL' ) ) {
    /**
     * Plugin dir url.
     */
    define( 'WOO_PAYLATE_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
}
if ( !defined( 'WOO_PAYLATE_FILE' ) ) {
    /**
     * Main plugin file.
     */
    define( 'WOO_PAYLATE_FILE', __FILE__ );
}
if ( !defined( 'WOO_PAYLATE_VERSION' ) ) {
    /**
     * Plugin version.
     */
    define( 'WOO_PAYLATE_VERSION', '1.3.1' );
}
/**
 * Create a helper function for easy SDK access.
 *
 * @return Freemius
 */
function wc_paylate_fs()
{
    global  $wc_paylate_fs ;
    
    if ( !isset( $wc_paylate_fs ) ) {
        // Include Freemius SDK.
        require_once dirname( __FILE__ ) . '/freemius/start.php';
        try {
            $wc_paylate_fs = fs_dynamic_init( array(
                'id'             => '1764',
                'slug'           => 'woo-paylate',
                'type'           => 'plugin',
                'public_key'     => 'pk_e0b286b8fbe8ce6636b609f47b6af',
                'is_premium'     => false,
                'has_addons'     => false,
                'has_paid_plans' => true,
                'menu'           => array(
                'first-path' => 'plugins.php',
                'slug'       => 'wc-paylate',
                'support'    => false,
                'parent'     => array(
                'slug' => 'woocommerce',
            ),
            ),
                'is_live'        => true,
            ) );
        } catch ( Freemius_Exception $e ) {
            die( esc_html__( 'Cannot initialize Freemius SDK', 'woo-paylate' ) );
        }
    }
    
    return $wc_paylate_fs;
}

// Init Freemius.
wc_paylate_fs();
// Signal that SDK was initiated.
do_action( 'wc_paylate_fs_loaded' );
/**
 * Get settings url.
 *
 * @return string
 */
function wc_paylate_fs_settings_url()
{
    return admin_url( 'admin.php?page=wc-settings&tab=checkout&section=paylate_gateway' );
}

wc_paylate_fs()->add_filter( 'connect_url', 'wc_paylate_fs_settings_url' );
wc_paylate_fs()->add_filter( 'after_skip_url', 'wc_paylate_fs_settings_url' );
wc_paylate_fs()->add_filter( 'after_connect_url', 'wc_paylate_fs_settings_url' );
wc_paylate_fs()->add_filter( 'after_pending_connect_url', 'wc_paylate_fs_settings_url' );
/**
 * Return instance of WC_PayLate_Plugin.
 *
 * @return WC_PayLate_Plugin
 */
function wc_paylate_plugin()
{
    static  $plugin ;
    
    if ( !isset( $plugin ) ) {
        
        if ( version_compare( PHP_VERSION, '5.3.0' ) >= 0 ) {
            require_once WOO_PAYLATE_PATH . '/vendor/autoload.php';
        } else {
            require_once WOO_PAYLATE_PATH . '/vendor/autoload_52.php';
        }
        
        $plugin = new WC_PayLate_Plugin();
    }
    
    return $plugin;
}

wc_paylate_plugin()->maybe_run();